@@ -16,18 +16,15 @@
 #![allow(non_snake_case)]
 #![allow(non_upper_case_globals)]
 
+include!(concat!(env!("OUT_DIR"), "/bindings.rs"));
+
 extern crate libc;
 
 use libc::c_int;
 
-mod bindings;
 #[cfg(test)]
 mod patches_tests;
 
-pub use bindings::*;
-
-include!("patches.rs");
-
 #[no_mangle]
 pub fn bz_internal_error(errcode: c_int) {
     panic!("bz internal error: {}", errcode);
